==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Task, Tasks"
: [
  "Úkol"
 ,"Úkoly"
 ,"Úkolů"
 ,"Úkolů"

]
, "Percent"
: "Procent"

, "Completed"
: "Dokončený"

, "Due"
: "Do"

, "Class"
: ""

, "Description"
: "Popis"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organizátor"

, "Priority"
: "Priorita"

, "Status, Status"
: [
  ""
 ,""
 ,""
 ,""

]
, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Musíte zadat termín dokončení, protože je nastaven alarm!"

, "Summary"
: "Přehled"

, "Due date"
: "Termín dokončení"

, "Add Responsible ..."
: "Přidat zodpovědnou osobu ..."

, "Notes"
: "Poznámky"

, "Enter description..."
: "Zadejte popis..."

, "Percentage"
: "Procenta"

, "Tasks"
: "Úkoly"

, "to do list, to do lists"
: [
  "seznam úkolů"
 ,"seznamy úkolů"
 ,"seznamů úkolů"
 ,"seznamů úkolů"

]
, "to do lists"
: "seznamy úkolů"

, "Quick Search"
: ""

, "Due Date"
: "Termín dokončení"

, "Responsible"
: "Zodpovídá"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Čas vytvoření"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Opravdu chcete smazat vybraný úkol?"
 ,"Opravdu chcete smazat vybrané úkoly?"
 ,"Opravdu chcete smazat vybrané úkoly?"
 ,"Opravdu chcete smazat vybrané úkoly?"

]
, "Attachments"
: ""

, "Tags"
: "Štítky"

, "Lead name"
: ""

, "Add a task..."
: "Přidat úkol..."

, "All my tasks"
: "Všechny mé úkoly"

, "Default Favorite"
: "Výchozí oblíbené položky úkolů"

, "The default favorite which is loaded on Tasks startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění úkolů"

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: "spravovat sdílené seznamy úkolů"

, "Create new shared tasks lists"
: "Vytvořit nové sdílené seznamy úkolů"

, "manage shared tasks favorites"
: "spravovat sdílené oblíbené položky úkolů"

, "Create or update shared tasks favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky úkolů"

, "%s's personal tasks"
: "osobní úkoly uživatele %s"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Všechny úkoly z mých seznamů"

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "Úkol"

, "Status"
: ""

, "to do list"
: "seznam úkolů"

, "Do you really want to delete the selected task?"
: "Opravdu chcete smazat vybraný úkol?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Musíte zadat termín dokončení, protože je nastaven alarm!"

, "Summary"
: "Přehled"

, "Due date"
: "Termín dokončení"

, "Priority"
: "Priorita"

, "Organizer"
: "Organizátor"

, "Add Responsible ..."
: "Přidat zodpovědnou osobu ..."

, "Notes"
: "Poznámky"

, "Enter description..."
: "Zadejte popis..."

, "Percentage"
: "Procenta"

, "Status, Status"
: [
  ""
 ,""
 ,""
 ,""

]
, "Completed"
: "Dokončený"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Opravdu chcete smazat vybraný úkol?"
 ,"Opravdu chcete smazat vybrané úkoly?"
 ,"Opravdu chcete smazat vybrané úkoly?"
 ,"Opravdu chcete smazat vybrané úkoly?"

]
, "Attachments"
: ""

, "Tags"
: "Štítky"

, "Lead name"
: ""

, "Add a task..."
: "Přidat úkol..."

, "Due Date"
: "Termín dokončení"

, "Percent"
: "Procent"

, "Responsible"
: "Zodpovídá"

, "Task, Tasks"
: [
  "Úkol"
 ,"Úkoly"
 ,"Úkolů"
 ,"Úkolů"

]
, "Tasks"
: "Úkoly"

, "to do list, to do lists"
: [
  "seznam úkolů"
 ,"seznamy úkolů"
 ,"seznamů úkolů"
 ,"seznamů úkolů"

]
, "to do lists"
: "seznamy úkolů"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Čas vytvoření"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: "Všechny mé úkoly"

, "Default Favorite"
: "Výchozí oblíbené položky úkolů"

, "The default favorite which is loaded on Tasks startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění úkolů"

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "osobní úkoly uživatele %s"

, "GENDER_Task"
: ""

, "Due"
: "Do"

, "Class"
: ""

, "Description"
: "Popis"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Všechny úkoly z mých seznamů"

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: "spravovat sdílené seznamy úkolů"

, "Create new shared tasks lists"
: "Vytvořit nové sdílené seznamy úkolů"

, "manage shared tasks favorites"
: "spravovat sdílené oblíbené položky úkolů"

, "Create or update shared tasks favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky úkolů"

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "Opravdu chcete smazat vybraný úkol?"

, "Task"
: "Úkol"

, "to do list"
: "seznam úkolů"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
